create_restricted_role

Function create_restricted_role 

pub async fn create_restricted_role(
    db: &DbPool,
    db_name: &str,
    role_name: &str,
    password: &str,
) -> DbResult<()>
Sets up and locks down a database role.

Running this requires using an account with a higher level of access than the standard db user

db - Should be the tenant database db_name - Name of the tenant database role_name - Name of the user role to create and setup password - Password to assign the user role