create_restricted_role_aws_iam

Function create_restricted_role_aws_iam 

pub async fn create_restricted_role_aws_iam(
    db: &DbPool,
    db_name: &str,
    role_name: &str,
) -> DbResult<()>
Sets up and locks down a database role.

This database role is granted rds_iam to allow access to this role through AWS IAM

Running this requires using an account with a higher level of access than the standard db user.

db - Should be the tenant database db_name - Name of the tenant database role_name - Name of the user role to create and setup