delete_role

Function delete_role 

pub async fn delete_role(db: &DbPool, role_name: &str) -> DbResult<()>
Delete a database role.

Running this requires using an account with a higher level of access than the standard db user