Constants
Functions
- apply_
migration - Apply a migration to the specific database
- apply_
root_ migrations - Applies migrations to the root, only applies migrations that haven’t already been applied
- apply_
tenant_ migrations - Applies migrations to the provided tenant, only applies migrations that haven’t already been applied
- force_
apply_ tenant_ migrations - Applies migrations without checking if migrations have already been applied
- get_
pending_ root_ migrations - Get all pending migrations for the root that have not been applied yet
- get_
pending_ tenant_ migrations - Get all pending migrations for a tenant that have not been applied yet
- initialize_
root_ migrations - Initialize the table used for root migration tracking