pub async fn get_pending_root_migrations(
db: impl DbExecutor<'_>,
) -> DbResult<Vec<String>>Expand description
Get all pending migrations for the root that have not been applied yet
pub async fn get_pending_root_migrations(
db: impl DbExecutor<'_>,
) -> DbResult<Vec<String>>Get all pending migrations for the root that have not been applied yet