pub async fn initialize_root_migrations(db: impl DbExecutor<'_>) -> DbResult<()>Expand description
Initialize the table used for root migration tracking
(Must be performed before normal migrations can happen otherwise tracking will fail)
pub async fn initialize_root_migrations(db: impl DbExecutor<'_>) -> DbResult<()>Initialize the table used for root migration tracking
(Must be performed before normal migrations can happen otherwise tracking will fail)