pub struct GeneratedFile {
pub id: GeneratedFileId,
pub file_id: FileId,
pub mime: String,
pub ty: GeneratedFileType,
pub hash: String,
pub file_key: String,
pub created_at: DateTime<Utc>,
}Expand description
File generated as an artifact of an uploaded file
Fields
id: GeneratedFileIdUnique identifier for the file
file_id: FileIdFile this generated file belongs to
mime: StringMime type of the generated file content
ty: GeneratedFileTypeType of the generated file
hash: StringHash of the file this was generated from
file_key: StringS3 key pointing to the file
created_at: DateTime<Utc>When the file was created
Implementations
Sourceimpl GeneratedFile
impl GeneratedFile
pub async fn create( db: impl DbExecutor<'_>, __arg1: CreateGeneratedFile, ) -> DbResult<GeneratedFile>
Sourcepub async fn delete(self, db: impl DbExecutor<'_>) -> DbResult<PgQueryResult>
pub async fn delete(self, db: impl DbExecutor<'_>) -> DbResult<PgQueryResult>
Deletes the generated file
pub async fn find_all( db: impl DbExecutor<'_>, file_id: FileId, ) -> DbResult<Vec<GeneratedFile>>
Sourcepub async fn find(
db: impl DbExecutor<'_>,
scope: &DocumentBoxScopeRaw,
file_id: FileId,
ty: GeneratedFileType,
) -> DbResult<Option<GeneratedFile>>
pub async fn find( db: impl DbExecutor<'_>, scope: &DocumentBoxScopeRaw, file_id: FileId, ty: GeneratedFileType, ) -> DbResult<Option<GeneratedFile>>
Finds a specific file using its full path scope -> folder -> file