Link

Struct Link 

pub struct Link {
    pub id: LinkId,
    pub name: String,
    pub value: String,
    pub pinned: bool,
    pub folder_id: FolderId,
    pub created_at: DateTime<Utc>,
    pub created_by: Option<UserId>,
}

Fields

id: LinkId

Unique identifier for the link

name: String

Name of the link

value: String

value of the link

pinned: bool

Whether the link is pinned

folder_id: FolderId

Parent folder ID

created_at: DateTime<Utc>

When the link was created

created_by: Option<UserId>

User who created the link

Implementations

pub async fn create( db: impl DbExecutor<'_>, __arg1: CreateLink, ) -> DbResult<Link>

pub async fn move_to_folder( self, db: impl DbExecutor<'_>, folder_id: FolderId, ) -> DbResult<Link>

pub async fn rename( self, db: impl DbExecutor<'_>, name: String, ) -> DbResult<Link>

pub async fn set_pinned( self, db: impl DbExecutor<'_>, pinned: bool, ) -> DbResult<Link>

pub async fn update_value( self, db: impl DbExecutor<'_>, value: String, ) -> DbResult<Link>

pub async fn all( db: impl DbExecutor<'_>, offset: u64, page_size: u64, ) -> DbResult<Vec<LinkWithScope>>

pub async fn find( db: impl DbExecutor<'_>, scope: DocumentBoxScopeRawRef<'_>, link_id: LinkId, ) -> DbResult<Option<Link>>

pub async fn resolve_path( db: impl DbExecutor<'_>, link_id: LinkId, ) -> DbResult<Vec<FolderPathSegment>>

Collects the IDs and names of all parent folders of the provided folder

pub async fn find_by_parent( db: impl DbExecutor<'_>, parent_id: FolderId, ) -> DbResult<Vec<Link>>

Finds all links within the provided parent folder

pub async fn delete(&self, db: impl DbExecutor<'_>) -> DbResult<PgQueryResult>

Deletes the link

pub async fn resolve_with_extra_mixed_scopes( db: impl DbExecutor<'_>, links_scope_with_id: Vec<DocboxInputPair<'_>>, ) -> DbResult<Vec<WithFullPathScope<LinkWithExtra>>>

Finds a collection of links that are within various document box scopes, resolves both the links themselves and the folder path to traverse to get to each link

pub async fn resolve_with_extra( db: impl DbExecutor<'_>, scope: &DocumentBoxScopeRaw, link_ids: Vec<Uuid>, ) -> DbResult<Vec<WithFullPath<LinkWithExtra>>>

Finds a collection of links that are all within the same document box, resolves both the links themselves and the folder path to traverse to get to each link

pub async fn find_by_parent_with_extra( db: impl DbExecutor<'_>, parent_id: FolderId, ) -> DbResult<Vec<LinkWithExtra>>

Finds all links within the provided parent folder

pub async fn find_with_extra( db: impl DbExecutor<'_>, scope: &DocumentBoxScopeRaw, link_id: LinkId, ) -> DbResult<Option<LinkWithExtra>>

pub async fn total_count(db: impl DbExecutor<'_>) -> DbResult<i64>

Get the total number of folders in the tenant