pub struct LinkResolvedMetadata {
pub url: String,
pub metadata: StoredResolvedWebsiteMetadata,
pub expires_at: DateTime<Utc>,
}Fields
url: StringURL of the resolved metadata
metadata: StoredResolvedWebsiteMetadataThe metadata itself
expires_at: DateTime<Utc>Timestamp of when the metadata will expire
Implementations
Sourceimpl LinkResolvedMetadata
impl LinkResolvedMetadata
Sourcepub async fn create(
db: impl DbExecutor<'_>,
create: CreateLinkResolvedMetadata,
) -> DbResult<()>
pub async fn create( db: impl DbExecutor<'_>, create: CreateLinkResolvedMetadata, ) -> DbResult<()>
Create and insert a new resolved link metadata
Sourcepub async fn query(
db: impl DbExecutor<'_>,
url: &str,
) -> DbResult<Option<LinkResolvedMetadata>>
pub async fn query( db: impl DbExecutor<'_>, url: &str, ) -> DbResult<Option<LinkResolvedMetadata>>
Query the resolved link metadata for the provided URL
Sourcepub async fn delete_expired(
db: impl DbExecutor<'_>,
before: DateTime<Utc>,
) -> DbResult<PgQueryResult>
pub async fn delete_expired( db: impl DbExecutor<'_>, before: DateTime<Utc>, ) -> DbResult<PgQueryResult>
Deletes all metadata where the expiry date is less than before