Presigned Upload Task
Background uploading task, handles storing data about pending pre-signed S3 file uploads. Used to track completion and uploads that were cancelled or failed
Structs
- Create
Presigned Upload Task - Required data to create a presigned upload task
- Presigned
Upload Task - Task storing the details for a presigned upload task