pub struct Task {
pub id: Uuid,
pub document_box: DocumentBoxScopeRaw,
pub status: TaskStatus,
pub output_data: Option<Value>,
pub created_at: DateTime<Utc>,
pub completed_at: Option<DateTime<Utc>>,
}Expand description
Represents a stored asynchronous task progress
Fields
id: UuidUnique ID of the task
document_box: DocumentBoxScopeRawID of the document box the task belongs to
status: TaskStatusStatus of the task
output_data: Option<Value>Output data from the task completion
created_at: DateTime<Utc>When the task was created
completed_at: Option<DateTime<Utc>>Implementations
Sourceimpl Task
impl Task
Sourcepub async fn create(
db: impl DbExecutor<'_>,
document_box: DocumentBoxScopeRaw,
) -> DbResult<Task>
pub async fn create( db: impl DbExecutor<'_>, document_box: DocumentBoxScopeRaw, ) -> DbResult<Task>
Stores / updates the stored user data, returns back the user ID
pub async fn find( db: impl DbExecutor<'_>, id: TaskId, document_box: DocumentBoxScopeRawRef<'_>, ) -> DbResult<Option<Task>>
Sourcepub async fn complete_task(
&mut self,
db: impl DbExecutor<'_>,
status: TaskStatus,
output_data: Option<Value>,
) -> DbResult<()>
pub async fn complete_task( &mut self, db: impl DbExecutor<'_>, status: TaskStatus, output_data: Option<Value>, ) -> DbResult<()>
Mark the task as completed and set its output data
Sourcepub async fn delete_expired(
db: impl DbExecutor<'_>,
before: DateTime<Utc>,
) -> DbResult<PgQueryResult>
pub async fn delete_expired( db: impl DbExecutor<'_>, before: DateTime<Utc>, ) -> DbResult<PgQueryResult>
Deletes all tasks where the creation date is older than the before date