Module migrations

Module migrations 

Constants

ROOT_MIGRATIONS
TENANT_MIGRATIONS

Functions

apply_migration
Apply a migration to the specific database
apply_root_migrations
Applies migrations to the root, only applies migrations that haven’t already been applied
apply_tenant_migrations
Applies migrations to the provided tenant, only applies migrations that haven’t already been applied
force_apply_tenant_migrations
Applies migrations without checking if migrations have already been applied
get_pending_root_migrations
Get all pending migrations for the root that have not been applied yet
get_pending_tenant_migrations
Get all pending migrations for a tenant that have not been applied yet
initialize_root_migrations
Initialize the table used for root migration tracking