Transaction

Struct Transaction 

pub struct Transaction<'c, DB>
where DB: Database,
{ /* private fields */ }
SQLx re-exports for other projects An in-progress database transaction or savepoint.

A transaction starts with a call to Pool::begin or Connection::begin.

A transaction should end with a call to commit or rollback. If neither are called before the transaction goes out-of-scope, rollback is called. In other words, rollback is called on drop if the transaction is still in-progress.

A savepoint is a special mark inside a transaction that allows all commands that are executed after it was established to be rolled back, restoring the transaction state to what it was at the time of the savepoint.

A transaction can be used as an Executor when performing queries:

let mut tx = conn.begin().await?;

let result = sqlx::query("DELETE FROM \"testcases\" WHERE id = $1")
    .bind(id)
    .execute(&mut *tx)
    .await?
    .rows_affected();

tx.commit().await

Implementations

Source

impl<'c, DB> Transaction<'c, DB>
where DB: Database,

pub async fn commit(self) -> Result<(), Error>

Commits this transaction or savepoint.

pub async fn rollback(self) -> Result<(), Error>

Aborts this transaction or savepoint.